@@ -1,15 +1,16 @@
 use super::flags::Id3v2TagFlags;
-use super::frame::content::{EncodedTextFrame, LanguageFrame};
 use super::frame::id::FrameID;
 use super::frame::{Frame, FrameFlags, FrameValue};
 use super::util::text_utils::TextEncoding;
 use super::Id3v2Version;
 use crate::error::{LoftyError, Result};
 use crate::id3::v2::frame::FrameRef;
-use crate::tag_traits::{Accessor, TagExt};
-use crate::types::item::{ItemKey, ItemValue, TagItem};
-use crate::types::picture::{Picture, PictureType};
-use crate::types::tag::{Tag, TagType};
+use crate::id3::v2::items::encoded_text_frame::EncodedTextFrame;
+use crate::id3::v2::items::language_frame::LanguageFrame;
+use crate::picture::{Picture, PictureType};
+use crate::tag::item::{ItemKey, ItemValue, TagItem};
+use crate::tag::{Tag, TagType};
+use crate::traits::{Accessor, TagExt};
 
 use std::borrow::Cow;
 use std::convert::TryInto;
@@ -73,7 +74,7 @@ macro_rules! impl_accessor {
 ///
 /// When converting from a [`Tag`](crate::Tag) to an `Id3v2Tag`, some frames may need editing.
 ///
-/// * [`ItemKey::Comment`](crate::ItemKey::Comment) and [`ItemKey::Lyrics`](crate::ItemKey::Lyrics) - Rather than be a normal text frame, these require a [`LanguageFrame`].
+/// * [`ItemKey::Comment`](crate::ItemKey::Comment) and [`ItemKey::Lyrics`](crate::ItemKey::Lyrics) - Unlike a normal text frame, these require a [`LanguageFrame`].
 /// An attempt is made to create this information, but it may be incorrect.
 ///    * `language` - Assumed to be "eng"
 ///    * `description` - Left empty, which is invalid if there are more than one of these frames. These frames can only be identified
@@ -318,6 +319,10 @@ impl TagExt for Id3v2Tag {
 	fn remove_from(&self, file: &mut File) -> std::result::Result<(), Self::Err> {
 		TagType::Id3v2.remove_from(file)
 	}
+
+	fn clear(&mut self) {
+		self.frames.clear();
+	}
 }
 
 impl From<Id3v2Tag> for Tag {
@@ -376,6 +381,7 @@ impl From<Id3v2Tag> for Tag {
 					tag.push_picture(picture);
 					continue;
 				},
+				FrameValue::Popularimeter(_) => continue,
 				FrameValue::Binary(binary) => ItemValue::Binary(binary),
 			};
 
@@ -422,6 +428,15 @@ pub(crate) struct Id3v2TagRef<'a, I: Iterator<Item = FrameRef<'a>> + 'a> {
 	pub(crate) frames: I,
 }
 
+impl<'a> Id3v2TagRef<'a, std::iter::Empty<FrameRef<'a>>> {
+	pub(crate) fn empty() -> Self {
+		Self {
+			flags: Id3v2TagFlags::default(),
+			frames: std::iter::empty(),
+		}
+	}
+}
+
 // Create an iterator of FrameRef from a Tag's items for Id3v2TagRef::new
 pub(crate) fn tag_frames(tag: &Tag) -> impl Iterator<Item = FrameRef<'_>> + '_ {
 	let items = tag
@@ -457,15 +472,16 @@ impl<'a, I: Iterator<Item = FrameRef<'a>> + 'a> Id3v2TagRef<'a, I> {
 
 #[cfg(test)]
 mod tests {
+	use crate::id3::v2::items::popularimeter::Popularimeter;
 	use crate::id3::v2::{
 		read_id3v2_header, Frame, FrameFlags, FrameID, FrameValue, Id3v2Tag, Id3v2Version,
 		LanguageFrame, TextEncoding,
 	};
-	use crate::tag_utils::test_utils::read_path;
+	use crate::tag::utils::test_utils::read_path;
 	use crate::{MimeType, Picture, PictureType, Tag, TagExt, TagType};
 
 	fn read_tag(path: &str) -> Id3v2Tag {
-		let tag_bytes = crate::tag_utils::test_utils::read_path(path);
+		let tag_bytes = crate::tag::utils::test_utils::read_path(path);
 
 		let mut reader = std::io::Cursor::new(&tag_bytes[..]);
 
@@ -592,7 +608,7 @@ mod tests {
 
 		let tag: Tag = id3v2.into();
 
-		crate::tag_utils::test_utils::verify_tag(&tag, true, true);
+		crate::tag::utils::test_utils::verify_tag(&tag, true, true);
 	}
 
 	#[test]
@@ -633,7 +649,7 @@ mod tests {
 			);
 		}
 
-		let tag = crate::tag_utils::test_utils::create_tag(TagType::Id3v2);
+		let tag = crate::tag::utils::test_utils::create_tag(TagType::Id3v2);
 
 		let id3v2_tag: Id3v2Tag = tag.into();
 
@@ -819,4 +835,22 @@ mod tests {
 			})
 		);
 	}
+
+	#[test]
+	fn popm_frame() {
+		let parsed_tag = read_tag("tests/tags/assets/id3v2/test_popm.id3v24");
+
+		assert_eq!(parsed_tag.frames.len(), 1);
+		let popm_frame = parsed_tag.frames.first().unwrap();
+
+		assert_eq!(popm_frame.id, FrameID::Valid(String::from("POPM")));
+		assert_eq!(
+			popm_frame.value,
+			FrameValue::Popularimeter(Popularimeter {
+				email: String::from("foo@bar.com"),
+				rating: 196,
+				counter: 65535
+			})
+		)
+	}
 }
