@@ -31,7 +31,7 @@ fn verify_frame(frame: &FrameRef<'_>) -> Result<()> {
 		| ("TXXX", FrameValue::UserText(_))
 		| ("WXXX", FrameValue::UserURL(_))
 		| (_, FrameValue::Binary(_))
-		| ("WFED" | "GRP1", FrameValue::Text { .. }) => Ok(()),
+		| ("WFED" | "GRP1" | "MVNM" | "MVIN", FrameValue::Text { .. }) => Ok(()),
 		(id, FrameValue::Text { .. }) if id.starts_with('T') => Ok(()),
 		(id, FrameValue::URL(_)) if id.starts_with('W') => Ok(()),
 		(id, frame_value) => Err(Id3v2Error::new(Id3v2ErrorKind::BadFrame(
@@ -44,6 +44,7 @@ fn verify_frame(frame: &FrameRef<'_>) -> Result<()> {
 				FrameValue::URL(_) => "URL",
 				FrameValue::UserURL(_) => "UserURL",
 				FrameValue::Picture { .. } => "Picture",
+				FrameValue::Popularimeter(_) => "Popularimeter",
 				FrameValue::Binary(_) => "Binary",
 			},
 		))
