@@ -2,7 +2,7 @@ use crate::error::{ErrorKind, LoftyError, Result};
 #[cfg(feature = "id3v2")]
 use crate::id3::v2;
 #[allow(unused_imports)]
-use crate::types::tag::{Tag, TagType};
+use crate::tag::{Tag, TagType};
 
 use std::fs::File;
 
