@@ -6,20 +6,19 @@
 //!
 //! # Supported Formats
 //!
+//! | File Format | Metadata Format(s)                   |
+//! |-------------|--------------------------------------|
+//! | Ape         | `APEv2`, `APEv1`, `ID3v2`\*, `ID3v1` |
+//! | AIFF        | `ID3v2`, `Text Chunks`               |
+//! | FLAC        | `Vorbis Comments`, `ID3v2`\*         |
+//! | MP3         | `ID3v2`, `ID3v1`, `APEv2`, `APEv1`   |
+//! | MP4         | `iTunes-style ilst`                  |
+//! | Opus        | `Vorbis Comments`                    |
+//! | Ogg Vorbis  | `Vorbis Comments`                    |
+//! | Speex       | `Vorbis Comments`                    |
+//! | WAV         | `ID3v2`, `RIFF INFO`                 |
 //!
-//! | File Format | Metadata Format(s)                  |
-//! |-------------|-------------------------------------|
-//! | Ape         | `APEv2`, `APEv1`, `ID3v2`*, `ID3v1` |
-//! | AIFF        | `ID3v2`, `Text Chunks`              |
-//! | FLAC        | `Vorbis Comments`                   |
-//! | MP3         | `ID3v2`, `ID3v1`, `APEv2`, `APEv1`  |
-//! | MP4         | `iTunes-style ilst`                 |
-//! | Opus        | `Vorbis Comments`                   |
-//! | Ogg Vorbis  | `Vorbis Comments`                   |
-//! | Speex       | `Vorbis Comments`                   |
-//! | WAV         | `ID3v2`, `RIFF INFO`                |
-//!
-//! \* APE does not officially support ID3v2, so the tag will be **read only**
+//! \* The tag will be **read only**, due to lack of official support
 //!
 //! # Examples
 //!
@@ -160,34 +159,38 @@
 	clippy::single_match_else,
 	clippy::similar_names,
 	clippy::tabs_in_doc_comments,
-	clippy::len_without_is_empty
+	clippy::len_without_is_empty,
+	clippy::needless_late_init
 )]
 #![cfg_attr(docsrs, feature(doc_auto_cfg))]
 
 pub mod ape;
 pub mod error;
+pub(crate) mod file;
+pub mod flac;
 pub mod id3;
 pub mod iff;
 pub(crate) mod macros;
 pub mod mp3;
 pub mod mp4;
 pub mod ogg;
+pub(crate) mod picture;
 mod probe;
-mod tag_traits;
-pub(crate) mod tag_utils;
-mod types;
+pub(crate) mod properties;
+pub(crate) mod tag;
+mod traits;
 
 pub use crate::error::{LoftyError, Result};
 
 pub use crate::probe::{read_from, read_from_path, Probe};
 
-pub use crate::types::file::{AudioFile, FileType, TaggedFile};
-pub use crate::types::item::{ItemKey, ItemValue, TagItem};
-pub use crate::types::picture::{MimeType, Picture, PictureType};
-pub use crate::types::properties::FileProperties;
-pub use crate::types::tag::{Tag, TagType};
+pub use crate::file::{AudioFile, FileType, TaggedFile};
+pub use crate::picture::{MimeType, Picture, PictureType};
+pub use crate::properties::FileProperties;
+pub use crate::tag::{Tag, TagType};
+pub use tag::item::{ItemKey, ItemValue, TagItem};
 
-pub use crate::tag_traits::{Accessor, TagExt};
+pub use crate::traits::{Accessor, TagExt};
 
 #[cfg(feature = "vorbis_comments")]
-pub use crate::types::picture::PictureInformation;
+pub use picture::PictureInformation;
