@@ -4,10 +4,10 @@ use super::find_last_page;
 #[cfg(feature = "vorbis_comments")]
 use super::tag::VorbisComments;
 use crate::error::Result;
+use crate::file::{AudioFile, FileType, TaggedFile};
 use crate::ogg::constants::{OPUSHEAD, OPUSTAGS};
-use crate::types::file::{AudioFile, FileType, TaggedFile};
-use crate::types::properties::FileProperties;
-use crate::types::tag::TagType;
+use crate::properties::FileProperties;
+use crate::tag::TagType;
 use properties::OpusProperties;
 
 use std::io::{Read, Seek};
